@@ -6,10 +6,12 @@ import re
 from collections import OrderedDict
 
 import pefile
-from sflock.aux.decode_vbe_jse import DecodeVBEJSE
+from sflock.aux.decode_vbe_jse import decode_file as vbe_decode_file
+
 
 try:
     import yara
+
     cur_dir = os.path.dirname(os.path.abspath(__file__))
     shellcode_rules = yara.compile(filepath=os.path.join(cur_dir, "data", "yara", "shellcodes.yar"))
     archives_rules = yara.compile(filepath=os.path.join(cur_dir, "data", "yara", "archives.yar"))
@@ -21,6 +23,7 @@ except ImportError:
 try:
     from unicorn import Uc, UC_MODE_32, UC_MODE_64, UC_ARCH_X86, UC_HOOK_CODE, unicorn
     from unicorn.x86_const import UC_X86_REG_ESP
+
     HAVE_UNICORN = True
 except ImportError:
     HAVE_UNICORN = False
@@ -36,8 +39,44 @@ file_extensions = OrderedDict(
         ("msix", (b".msix", b".msixbundle")),
         ("pub", (b".pub",)),
         ("doc", (b".doc", b".dot", b".docx", b".dotx", b".docm", b".dotm", b".docb", b".rtf", b".mht", b".mso", b".wbk", b".wiz")),
-        ("xls", (b".xls", b".xlt", b".xlm", b".xlsx", b".xltx", b".xlsm", b".xltm", b".xlsb", b".xla", b".xlam", b".xll", b".xlw", b".slk", b".xll", b".csv")),
-        ("ppt", (b".ppt", b".ppa", b".pot", b".pps", b".pptx", b".pptm", b".potx", b".potm", b".ppam", b".ppsx", b".ppsm", b".sldx", b".sldm")),
+        (
+            "xls",
+            (
+                b".xls",
+                b".xlt",
+                b".xlm",
+                b".xlsx",
+                b".xltx",
+                b".xlsm",
+                b".xltm",
+                b".xlsb",
+                b".xla",
+                b".xlam",
+                b".xll",
+                b".xlw",
+                b".slk",
+                b".xll",
+                b".csv",
+            ),
+        ),
+        (
+            "ppt",
+            (
+                b".ppt",
+                b".ppa",
+                b".pot",
+                b".pps",
+                b".pptx",
+                b".pptm",
+                b".potx",
+                b".potm",
+                b".ppam",
+                b".ppsx",
+                b".ppsm",
+                b".sldx",
+                b".sldm",
+            ),
+        ),
         ("jar", (b".jar",)),
         # ("rar", (b".rar",)),
         ("reg", (b".reg",)),
@@ -47,7 +86,7 @@ file_extensions = OrderedDict(
         # ("msg", (b".msg",, b".rpmsg")),
         # ("eml", (b".eml", b".ics")),
         ("js", (b".js", b".jse")),
-        ("ie", (b".html", b".url")), # b".htm",
+        ("ie", (b".html", b".url")),  # b".htm",
         ("xps", (b".xps",)),
         ("hta", (b".hta",)),
         ("mht", (b".mht",)),
@@ -63,7 +102,8 @@ file_extensions = OrderedDict(
         ("zip", (b".zip",)),
         ("cpl", (b".cpl",)),
         ("ichitaro", (b".jtd", b".jtdc", b".jttc", b".jtt")),
-        ("one", (b".one", b".onetoc2"))
+        ("inf", (b".inf",)),
+        ("one", (b".one", b".onetoc2")),
     ]
 )
 
@@ -88,6 +128,7 @@ mimes = OrderedDict(
         ("application/x-dosexec", "exe"),
         ("application/vnd.ms-cab-compressed", "cab"),
         ("application/pdf", "pdf"),
+        ("application/x-setupscript", "inf"),
     ]
 )
 
@@ -106,7 +147,7 @@ magics = OrderedDict(
         ("MS-DOS executable PE32 executable (DLL)", "dll"),
         ("PE32 executable", "exe"),
         ("PE32+ executable", "exe"),
-        ('MS-DOS executable, MZ for MS-DOS', "exe"),
+        ("MS-DOS executable, MZ for MS-DOS", "exe"),
         ("Microsoft PowerPoint", "ppt"),
         ("Microsoft Office Excel", "xls"),
         ("Microsoft Excel", "xls"),
@@ -148,7 +189,11 @@ magics = OrderedDict(
     ]
 )
 
+
 def detect_shellcode(f):
+
+    if f.contents[6:10] == b"JFIF":
+        return
     """
     if HAVE_YARA:
         matches = shellcode_rules.match(data=f.contents)
@@ -172,6 +217,7 @@ def detect_shellcode(f):
         return "Shellcode"
     return False
 
+
 def hook_instr(uc, address, size, mode):
     global shellcode_count32, shellcode_count64, shellcode_last_address
     if mode == UC_MODE_32:
@@ -180,34 +226,39 @@ def hook_instr(uc, address, size, mode):
         shellcode_count64 += 1
     shellcode_last_address = address
 
+
 def emulate(data, mode):
     try:
         stack = 0x90000
         uc = Uc(UC_ARCH_X86, mode)
-        uc.mem_map(stack, 0x1000*10)
+        uc.mem_map(stack, 0x1000 * 10)
         uc.mem_map(shellcode_code_base, 0x100000)
         uc.mem_write(shellcode_code_base, data)
-        uc.reg_write(UC_X86_REG_ESP, stack+0x1000)
+        uc.reg_write(UC_X86_REG_ESP, stack + 0x1000)
         uc.hook_add(UC_HOOK_CODE, hook_instr, user_data=mode)
-        uc.emu_start(shellcode_code_base, shellcode_code_base+len(data), 0, shellcode_limit)
+        uc.emu_start(shellcode_code_base, shellcode_code_base + len(data), 0, shellcode_limit)
     except unicorn.UcError:
         pass
 
+
 def inp(f):
     if b"InPage Arabic Document" in f.contents:
         return "inp"
 
+
 def mso(f):
     if b"mso-application" in f.contents and b"Word.Document" in f.contents:
         return "doc"
 
+
 def sct(f):
     if f.filename and f.filename.endswith(b".sct"):
-        if re.search(br"(?is)<\?XML.*?<scriptlet.*?<registration", f.contents):
+        if re.search(rb"(?is)<\?XML.*?<scriptlet.*?<registration", f.contents):
             return "sct"
         else:
             return "hta"
 
+
 def xxe(f):
     if f.contents.startswith(b"MZ"):
         return None
@@ -257,10 +308,12 @@ def hta(f):
     if found >= 10:
         return "hta"
 
+
 def office_one(f):
     if f.contents.startswith(b"\xE4\x52\x5C\x7B\x8C\xD8\xA7\x4D\xAE\xB1\x53\x78\xD0\x29\x96\xD3"):
         return "one"
 
+
 def office_webarchive(f):
     if f.contents.startswith(b"MZ"):
         return None
@@ -302,10 +355,12 @@ def office_activemime(f):
     if f.contents.startswith((b"QWN0aXZlTWltZQ", b"ActiveMime")):
         return "doc"
 
+
 def msix(f):
     if all([pattern in f.contents for pattern in (b"Registry.dat", b"AppxManifest.xml")]):
         return "msix"
 
+
 def office_zip(f):
     if not f.get_child(b"[Content_Types].xml"):
         return
@@ -425,7 +480,9 @@ def visualbasic(f):
 
     VB_STRS = [
         b"Dim ",
+        b"\x00D\x00i\x00m\x00 ",
         b"dim ",
+        b"\s\x00d\x00i\x00m\x00 ",
         b"Set ",
         b"Attribute ",
         b"Public ",
@@ -449,7 +506,7 @@ def visualbasic(f):
 
 
 def java(f):
-    if not f.get_child(b"META-INF/MANIFEST.MF"):
+    if not f.get_child(b"META-INF/MANIFEST.MF") and not b"META-INF/MANIFEST.MF" in f.contents:
         return
     if f.get_child(b"AndroidManifest.xml"):
         return
@@ -474,9 +531,9 @@ def vbe_jse(f):
         return None
 
     if b"#@~^" in f.contents[:100]:
-        data = DecodeVBEJSE(f.contents, "")
+        data = vbe_decode_file("", f.contents)
         if data:
-            if re.findall(b"\s?Dim\s", data, re.I):
+            if re.findall(rb"\s?Dim\s", data, re.I) or re.findall(b"\s\x00D\x00i\x00m\x00\s", data, re.I):
                 return "vbs"
             else:
                 return "js"
@@ -490,6 +547,27 @@ def udf(f):
         if "archive_udf" in [rule.rule for rule in matches]:
             return "udf"
 
+
+def inf(f):
+    if f.contents.startswith(b"MZ"):
+        return None
+
+    STRINGS = [
+        # b"[version]",
+        b"Signature=",
+        b"AdvancedINF=",
+        b"[DefaultInstall_SingleUser]",
+        b"[DefaultInstall]",
+    ]
+
+    found = 0
+    for string in STRINGS:
+        found += f.contents.count(string)
+
+    if found >= 3:
+        return "inf"
+
+
 def identify(f, check_shellcode: bool = False):
     if not f.stream.read(0x1000):
         return
@@ -506,7 +584,10 @@ def identify(f, check_shellcode: bool = False):
 
     # Trusted mimes and magics should be applied before identifiers which could run on files within archives
     if f.mime in trusted_archive_mimes:
-        return trusted_archive_mimes[f.mime]
+        if f.mime == "application/zip" and not java(f):
+            return trusted_archive_mimes[f.mime]
+        else:
+            return trusted_archive_mimes[f.mime]
 
     for magic_types in trusted_archive_magics:
         if f.magic.startswith(magic_types):
@@ -532,6 +613,7 @@ def identify(f, check_shellcode: bool = False):
     if check_shellcode:
         return detect_shellcode(f)
 
+
 identifiers_special = [
     msix,
 ]
@@ -556,4 +638,5 @@ identifiers = [
     vbe_jse,
     sct,
     inp,
+    inf,
 ]
